summaryrefslogtreecommitdiff
path: root/include/asterisk/stasis_cache_pattern.h
diff options
context:
space:
mode:
authorGeorge Joseph <george.joseph@fairview5.com>2016-01-05 10:06:32 -0700
committerGeorge Joseph <george.joseph@fairview5.com>2016-01-05 12:29:31 -0600
commitd228b62fd437e02c0638684c1f44c92e5f1e3948 (patch)
treed1a4408b6242f0614e2c5fe6c7257e9648381cdf /include/asterisk/stasis_cache_pattern.h
parente13719bff1c4a723edf08252da17fef04b6f88cf (diff)
stasis_cache_pattern: Backport to 13
Somehow stasis_cache_pattern got out of sync between 13 and master and it was causing duplicate channel message issues in 13 when related to a specific endpoint. I.E. from statsd, 'endpoints.PJSIP.1174.channels 0|g' was being emitted twice. Backporting stasis_cache_pattern from master to 13 solved the issue and running the unit and testsuite tests confirmed that no new ones were created. ASTERISK-25317 #close Change-Id: Ia8707462f62d15eed14541c37f332a7bbbceb548
Diffstat (limited to 'include/asterisk/stasis_cache_pattern.h')
-rw-r--r--include/asterisk/stasis_cache_pattern.h21
1 files changed, 6 insertions, 15 deletions
diff --git a/include/asterisk/stasis_cache_pattern.h b/include/asterisk/stasis_cache_pattern.h
index 27761351a..e61d3e931 100644
--- a/include/asterisk/stasis_cache_pattern.h
+++ b/include/asterisk/stasis_cache_pattern.h
@@ -121,9 +121,12 @@ struct stasis_cp_single *stasis_cp_single_create(struct stasis_cp_all *all,
const char *name);
/*!
* \brief Create the 'one' side of the cache pattern.
*
- * Create the 'one' but do not automatically forward.
+ * Create the 'one' but do not automatically forward to the all's topic.
+ * This is useful when aggregating other topic's messages created with
+ * \c stasis_cp_single_create in another caching topic without replicating
+ * those messages in the all's topics.
*
* Dispose of using stasis_cp_single_unsubscribe().
*
@@ -131,22 +134,10 @@ struct stasis_cp_single *stasis_cp_single_create(struct stasis_cp_all *all,
* \param name Base name for the topics.
* \return One side instance
*/
-struct stasis_cp_single *stasis_cp_single_create_only(struct stasis_cp_all *all,
+struct stasis_cp_single *stasis_cp_sink_create(struct stasis_cp_all *all,
const char *name);
/*!
- * \brief Set up a topic and topic cache forward.
- *
- * Forward 'from' to 'to'.
- *
- * \param from Source 'one' side instance.
- * \param to Destination 'one' side instance.
- * \retval 0 Success
- * \retval -1 Failure
- */
-int stasis_cp_single_forward(struct stasis_cp_single *from, struct stasis_cp_single *to);
-
-/*!
* \brief Stops caching and forwarding messages.
*
* \param one One side of the cache pattern.
@@ -121,9 +121,12 @@ struct stasis_cp_single *stasis_cp_single_create(struct stasis_cp_all *all,
const char *name);
/*!
- * \brief Create the 'one' side of the cache pattern.
+ * \brief Create a sink in the cache pattern
*